@@ -59,8 +59,6 @@
  * Returns: A boolean indicating success and a calculated Display Ratio in the
  * dar_n and dar_d parameters.
  * The return value is FALSE in the case of integer overflow or other error.
- *
- * Since: 0.10.7
  */
 gboolean
 gst_video_calculate_display_ratio (guint * dar_n, guint * dar_d,
@@ -99,3 +97,24 @@ error_overflow:
     return FALSE;
   }
 }
+
+/**
+ * gst_video_alignment_reset:
+ * @align: a #GstVideoAlignment
+ *
+ * Set @align to its default values with no padding and no alignment.
+ */
+void
+gst_video_alignment_reset (GstVideoAlignment * align)
+{
+  gint i;
+
+  g_return_if_fail (align != NULL);
+
+  align->padding_top = 0;
+  align->padding_bottom = 0;
+  align->padding_left = 0;
+  align->padding_right = 0;
+  for (i = 0; i < GST_VIDEO_MAX_PLANES; i++)
+    align->stride_align[i] = 0;
+}
